==> nextcloud-app-spreed-1%3A6.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/es_NI.js <==
OC.L10N.register(
    "spreed",
    {
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Talk" : "Hablar",
    "Copy" : "Copiar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
    "Password required" : "Contraseña requerida",
    "Password" : "Contraseña",
    "Cancel" : "Cancelar",
    "Submit" : "Enviar",
    "Leave call" : "Dejar la llamada",
    "Join call" : "Unirse a la llamada",
    "Share link" : "Compartir liga",
    "Change password" : "Cambiar contraseña",
    "Set password" : "Establecer contraseña",
    "Name" : "Nombre",
    "Rename" : "Renombrar",
    "You" : "Tú",
    "No messages yet, start the conversation!" : "Aún no hay mensajes. ¡!Inicia la conversación!",
    "Send" : "Enviar",
    "Guest" : "Invitado",
    "[Unknown user name]" : "[Nombre de usuario desconocido]",
    "Error occurred while sending message" : "Se presentó un error al enviar el mensaje",
    "Edit" : "Editar",
    "No other people in this call" : "No hay más personas en esta llamada",
    "Waiting for {participantName} to join the call …" : "Esperando a que {participantName} se una a la llamada…",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
    "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
    "WebRTC is not supported in your browser :-/" : "WebRTC no se encuentra soportado en tu navegador :-/",
    "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
    "Waiting for camera and microphone permissions" : "Aguardando los permisos para la cámara y micrófono",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor da acceso a tu navegador para usar tu camara y micrófono poder usar esta aplicación. ",
    "Disable video" : "Deshabilitar video",
    "Share screen" : "Compartir la pantalla",
    "Show your screen" : "Mostrar tu pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por tu navegador. ",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "Screensharing options" : "Opciones de compartir pantalla",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Enable screensharing" : "Habilitar compartir pantalla",
    "moderator" : "moderador",
    "Demote from moderator" : "Degradar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove participant" : "Eliminar participante",
    "Your screen" : "Tu pantalla",
    "{participantName}'s screen" : "Pantalla de {participantName}",
    "Guest's screen" : "Pantalla del invitado",
    "Close" : "Cerrar",
    "Show screen" : "Mostrar pantalla",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "(Duration %s)" : "(Duración %s)",
    "You attended a call with {user1}" : "Tomaste una llamda con {user1}",
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados"],
    "You attended a call with {user1} and {user2}" : "Tuviste una llamada con {user1} y {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Tuviste una llamada con {user1}, {user2} y {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Tuviste una llamada con {user1}, {user2}, {user3} y {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Tuviste una llamada con {user1}, {user2}, {user3}, {user4} y {user5}",
    "_%n other_::_%n others_" : ["%n otro","otros %n"],
    "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Te invitaron a un cuarto de <strong>conversación</strong> o tuviste una <strong>llamada</strong>",
    "Talk to %s" : "Hablar con %s",
    "{user} wants to talk with you" : "{user} quiere hablar contigo",
    "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
    "Validate SSL certificate" : "Validar certificado SSL",
    "TURN server protocols" : "Protocolos del servidor TURN",
    "UDP and TCP" : "UDP y TCP",
    "UDP only" : "UDP únicamente",
    "TCP only" : "TCP únicamente",
    "Saved" : "Guardado",
    "Shared secret" : "Secreto compartido",
    "STUN servers" : "Servidores STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
    "TURN server" : "Servidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
    "Delete server" : "Borrar servidor",
    "Add new server" : "Agregar un servidor nuevo ",
    "TURN server shared secret" : "Secreto compartido del servidor TURN",
    "_%n other guest_::_%n other guests_" : [" %n otro invitado","%n otros invitados"],
    ", " : ",",
    "A group call has started" : "Una llamada en grupo ha iniciado",
    "This call is password-protected" : "Esta llamada está protegida con contraseña",
    "Signaling server" : "Señalizando al servidor"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/es_NI.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(Duración %s)",
    "You attended a call with {user1}" : "Tomaste una llamda con {user1}",
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados"],
    "You attended a call with {user1} and {user2}" : "Tuviste una llamada con {user1} y {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Tuviste una llamada con {user1}, {user2} y {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Tuviste una llamada con {user1}, {user2}, {user3} y {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Tuviste una llamada con {user1}, {user2}, {user3}, {user4} y {user5}",
    "_%n other_::_%n others_" : ["%n otro","otros %n"],
    "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
    "Talk" : "Hablar",
    "Guest" : "Invitado",
    "Talk to %s" : "Hablar con %s",
    "Join call" : "Unirse a la llamada",
    "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
    "Open settings" : "Abrir configuraciones",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "Leave call" : "Dejar la llamada",
    "Limit to groups" : "Limitar a grupos",
    "Everyone" : "Todos",
    "Save changes" : "Guardar cambios",
    "Saved!" : "¡Guardado!",
    "None" : "Ninguno",
    "User" : "Ususario",
    "Disabled" : "Deshabilitado",
    "Users" : "Usuarios",
    "Name" : "Nombre",
    "General settings" : "Configuraciones generales",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estatus",
    "Created at" : "Creado en",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Blocked" : "Bloqueado",
    "Shared secret" : "Secreto compartido",
    "Validate SSL certificate" : "Validar certificado SSL",
    "Saved" : "Guardado",
    "STUN servers" : "Servidores STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
    "TURN server protocols" : "Protocolos del servidor TURN",
    "Copy link" : "Copiar liga",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
    "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
    "Dismiss" : "Descartar",
    "Show your screen" : "Mostrar tu pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "Mute audio" : "Silenciar audio",
    "Disable video" : "Deshabilitar video",
    "Enable video" : "Habilitar el video",
    "Screensharing options" : "Opciones de compartir pantalla",
    "Enable screensharing" : "Habilitar compartir pantalla",
    "Grid view" : "Vista de cuadrícula",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Back" : "Atrás",
    "You" : "Tú",
    "Show screen" : "Mostrar pantalla",
    "Favorite" : "Hacer favorito",
    "Password protection" : "Protección con contraseña",
    "Enter a password" : "Ingresa una contraseña",
    "Save" : "Guardar",
    "Edit" : "Editar",
    "Password" : "Contraseña",
    "API token" : "Ficha del API",
    "Login" : "Iniciar sesión",
    "Nickname" : "Apodo",
    "Client ID" : "ID del cliente",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a tus favoritos",
    "Loading" : "Cargando",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Password protect" : "Proteger con contraseña",
    "Close" : "Cerrar",
    "Reply" : "Responder",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "moderator" : "moderador",
    "Demote from moderator" : "Degradar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove participant" : "Eliminar participante",
    "No results" : "No hay resultados",
    "Add users or groups" : "Agregar usuarios o grupos",
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Settings" : "Configuraciones ",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Search" : "Buscar",
    "Send" : "Enviar",
    "Default" : "Predeterminado",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
    "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
    "TURN server" : "Servidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
    "Android app" : "Aplicación android",
    "iOS app" : "Aplicación iOS",
    "Remove" : "Eliminar"
},
"nplurals=2; plural=(n != 1);");
